@@ -1,5 +1,5 @@
 # coding: utf-8
-from __future__ import absolute_import, unicode_literals, print_function
+from __future__ import absolute_import, unicode_literals
 
 import gc
 import os
@@ -12,7 +12,7 @@ from . import core
 
 show_default_optimize_code_points = core.show_default_optimize_code_points
 
-__version__ = '0.7.3'
+__version__ = '0.8.0'
 __doc__ = """
 VFB2UFO3
 DESCRIPTION
@@ -26,8 +26,8 @@ AFDKO tools for creating binary fonts while still working with Windows FontLab
 renaming of kerning glyph groups (FontLab classes). Providing a `.flc`
 (FontLab-class) file can speed up conversion significantly when font groups are
 not identifiable as first/second from their name. All glyph hints/links are
-ignored. A batch command can be created for use with `psautohint`, which
-supports hinting outlines with decimal coordinates.
+ignored by default; a batch command can be created for use with `psautohint`,
+which supports hinting outlines with decimal coordinates.
 
 INSTALLATION
 PyPi
@@ -80,8 +80,8 @@ written in C++ and Cython. The submodules are compiled into `.pyd` extension
 modules. To recompile the submodules, the PyPi `cython` package and a compiler
 for Cython to utilize during extension module compilation will be required.
 
-The some extension modules compiled from C++ require several DLLs included in
-the release `.zip` archive, FontLab installer, and PyPi package.
+Extension modules compiled from C++ require several DLLs from the GCC which are
+included in the release `.zip` archive, FontLab installer, and PyPi package.
 
 OPTIONAL
   cython
@@ -92,17 +92,22 @@ OPTIONAL
   pip install afdko
   https://github.com/adobe-type-tools/afdko
 
+  psautohint
+  pip install psautohint
+  https://github.com/adobe-type-tools/psautohint
+
   MinGW 32-bit/i686 GCC >= 9.3.0
   http://winlibs.com
   https://www.msys2.org
   http://mingw.org
 
+  SHA512
+  https://github.com/pr0f3ss/SHA512
+
 FUNCTIONALITY
-UFO output is produced without changes to the source font. The source font will
-be copied and UFOs will be created from the copy. If the font is multiple
-master, instances will be generated from the copy. If a specific `layer` or
-`instance_values` are not provided for a multiple master source font, a UFO
-will be generated for each master in the font.
+UFO output is produced without changes to the source font. If a specific
+`layer` or `instance_values` are not provided for a multiple master source
+font, a UFO will be generated for each master in the font.
 
 Fonts with a large number of glyphs benefit greatly from supplying additional
 glyph names to be optimized when removing overlaps (`glyphs_optimize_names`)
@@ -270,7 +275,8 @@ Optimize glyph name and code point lists
   of `'0x00ac'`-format strings, integers in hexadecimal-form (`0x00ac`), or
   numeric integers (`172`); values which cannot be converted to an integer will
   raise a `ValueError`. Only the first code point in each glyph's list of code
-  points (FontLab unicodes attribute) is checked for code point set membership.
+  points (FontLab glyph unicodes attribute) is checked for code point set
+  membership.
 
   A user-supplied glyph name list (`glyphs_optimize_names`) can be supplied to
   supplement the code point list for glyphs. Any glyphs containing components
@@ -366,6 +372,16 @@ feature files from `include()` statements to the chosen output directory. Also
 see KERN FEATURE OPTIONS and MARK FEATURE OPTIONS below for `kern` and `mark`
 feature options.
 
+Hint options
+If enabled, the `glyph_hints` option converts hints on export (glyph links are
+converted to hints). By default, hints will be created following the UFO3
+public.postscript.hints specification. The `glyphs_hints_afdko_v1` and
+`glyphs_hints_afdko_v2` options enables hints compatible with MakeOTF. SHA512
+provides the hashing algorithm for computing the glyph hint ids according to
+the UFO3 PostScript hint specification.
+
+`glyphs_hints_vertical_only` ignored horizontal hints/links
+
 Kern feature options
 Kern values will be scaled in parity with the output UFO. This scaling is
 independent from the created `.vfb` instance. A minimum value can be set using
@@ -522,9 +538,9 @@ E5 1650v3 @ 3.5 GHz CPU and a solid-state hard drive; CPUs with fewer cores
 and/or a hard disk drive increases file write times considerably.
 
 Times are per-instance (±.5 sec) and do not include time to load and parse user
-options, then copy the original font and prepare the copy for conversion to the
-UFO format. This prep time increases when not providing a FontLab-class
-(`.flc`) or `groups.plist` file.
+options, then copy the information from the original font to prepare for
+conversion to the UFO format. This prep time increases when not providing a
+FontLab-class (`.flc`) or `groups.plist` file.
 
 The `ufoz` option reduces build time considerably.
 
@@ -656,10 +672,24 @@ through to the UFO.
 Author
 Jameson R Spires
 
-License
+Licenses
 Source files are covered under the MIT License.
 
 Version history
+version 0.8.0
+a copy of the original font is no longer created, decreasing master processing
+overhead by a considerable amount
+re-inclusion of glyph hints/links
+`.glif` file creation performance improvements
+corrections to `mark` feature generation
+
+version 0.7.5
+small changes/corrections
+
+version 0.7.4
+corrections to makeOTF batch command creation
+corrections to `kern` feature generation
+
 version 0.7.3
 corrections to `mark` feature generation
 reverted to use of `"` from `'` in XML files for compatibility with makeOTF
@@ -808,12 +838,18 @@ def write_ufo(
 
 	glyphs_decompose=False,
 	glyphs_remove_overlaps=False,
+
 	glyphs_omit_names=[],
 	glyphs_omit_suffixes=[],
 	glyphs_optimize=True,
 	glyphs_optimize_code_points=[],
 	glyphs_optimize_names=[],
 
+	glyphs_hints=False,
+	glyphs_hints_vertical_only=False,
+	glyphs_hints_afdko_v1=False,
+	glyphs_hints_afdko_v2=False,
+
 	ufoz=False,
 	ufoz_compress=True,
 
